package com.ruoyi.project.patrol.dev.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.patrol.dev.mapper.TDevSprinklerMapper;
import com.ruoyi.project.patrol.dev.domain.TDevSprinkler;
import com.ruoyi.project.patrol.dev.service.ITDevSprinklerService;

/**
 * 自动喷淋灭火系统Service业务层处理
 * 
 * @author admin
 * @date 2023-11-01
 */
@Service
public class TDevSprinklerServiceImpl implements ITDevSprinklerService 
{
    @Autowired
    private TDevSprinklerMapper tDevSprinklerMapper;

    /**
     * 查询自动喷淋灭火系统
     * 
     * @param id 自动喷淋灭火系统主键
     * @return 自动喷淋灭火系统
     */
    @Override
    public TDevSprinkler selectTDevSprinklerById(Long id)
    {
        return tDevSprinklerMapper.selectTDevSprinklerById(id);
    }

    /**
     * 查询自动喷淋灭火系统列表
     * 
     * @param tDevSprinkler 自动喷淋灭火系统
     * @return 自动喷淋灭火系统
     */
    @Override
    public List<TDevSprinkler> selectTDevSprinklerList(TDevSprinkler tDevSprinkler)
    {
        return tDevSprinklerMapper.selectTDevSprinklerList(tDevSprinkler);
    }

    /**
     * 新增自动喷淋灭火系统
     * 
     * @param tDevSprinkler 自动喷淋灭火系统
     * @return 结果
     */
    @Override
    public int insertTDevSprinkler(TDevSprinkler tDevSprinkler)
    {
        return tDevSprinklerMapper.insertTDevSprinkler(tDevSprinkler);
    }

    /**
     * 修改自动喷淋灭火系统
     * 
     * @param tDevSprinkler 自动喷淋灭火系统
     * @return 结果
     */
    @Override
    public int updateTDevSprinkler(TDevSprinkler tDevSprinkler)
    {
        return tDevSprinklerMapper.updateTDevSprinkler(tDevSprinkler);
    }

    /**
     * 批量删除自动喷淋灭火系统
     * 
     * @param ids 需要删除的自动喷淋灭火系统主键
     * @return 结果
     */
    @Override
    public int deleteTDevSprinklerByIds(Long[] ids)
    {
        return tDevSprinklerMapper.deleteTDevSprinklerByIds(ids);
    }

    /**
     * 删除自动喷淋灭火系统信息
     * 
     * @param id 自动喷淋灭火系统主键
     * @return 结果
     */
    @Override
    public int deleteTDevSprinklerById(Long id)
    {
        return tDevSprinklerMapper.deleteTDevSprinklerById(id);
    }
}
